Learn R Programming

EMMAgeo (version 0.9.0)

test.lw: Function to test maximum valid lw value.

Description

This function performs the weight transformation of the data matrix after Klovan & Imbrie (1971) with different weight limits and returns the maximum value for which the transformation remains stable.

Usage

test.lw(X, lw)

Arguments

X
Numeric matrix with m samples (rows) and n variables (columns).
lw
Numeric vector specifying the weight transformation limit, i.e. quantile; default is 0.

Value

  • A list with objects
  • stepNumeric scalar with position of last valid value.
  • lw.maxNumeric scalar with last valid value of lw.

References

Dietze E, Hartmann K, Diekmann B, IJmker J, Lehmkuhl F, Opitz S, Stauch G, Wuennemann B, Borchers A. 2012. An end-member algorithm for deciphering modern detrital processes from lake sediments of Lake Donggi Cona, NE Tibetan Plateau, China. Sedimentary Geology 243-244: 169-180. Klovan JE, Imbrie J. 1971. An Algorithm and FORTRAN-IV Program for Large-Scale Q-Mode Factor Analysis and Calculation of Factor Scores. Mathematical Geology 3: 61-77.

See Also

EMMA, check.data, test.parameters

Examples

Run this code
## load example data set
data(X.artificial, envir = environment())

## create weight transformation limits vector
lw <- seq(0, 0.6, by = 0.02)

## test the vector
test.lw(X = X.artificial, lw = lw)

Run the code above in your browser using DataLab